@@ -71,7 +71,7 @@ usage() {
     echo ""
 }
 
-NVIDIA_BUG_REPORT_CHANGE='$Change: 32465251 $'
+NVIDIA_BUG_REPORT_CHANGE='$Change: 34238640 $'
 NVIDIA_BUG_REPORT_VERSION=`echo "$NVIDIA_BUG_REPORT_CHANGE" | tr -c -d "[:digit:]"`
 
 # Set the default filename so that it won't be empty in the usage message
@@ -668,29 +668,25 @@ append_file_or_dir_silent /usr/share/nvidia/nvidia-application-profiles-*-rc
     lspci=`which lspci 2> /dev/null | head -n 1`
 
     if [ $? -eq 0 -a -x "$lspci" ]; then
-        # Capture NVIDIA devices
-        echo "$lspci -d \"10de:*\" -v -xxx"
+        # Capture all devices in tree format along with vendor:device IDs
+        echo "$lspci -nntv"
         echo ""
-        $lspci -d "10de:*" -v -xxx 2> /dev/null
-        echo ""
-        echo "____________________________________________"
-        echo ""
-        # Capture PLX devices
-        echo "$lspci -d \"10b5:*\" -v -xxx"
-        echo ""
-        $lspci -d "10b5:*" -v -xxx 2> /dev/null
-        echo ""
-        echo "____________________________________________"
-        echo ""
-        echo "$lspci -t"
-        echo ""
-        $lspci -t 2> /dev/null
+        $lspci -nntv 2> /dev/null
         echo ""
         echo "____________________________________________"
         echo ""
+        # Capture class names and class ID  along with vendor:device IDs
         echo "$lspci -nn"
         echo ""
         $lspci -nn 2> /dev/null
+        echo ""
+        echo "____________________________________________"
+        echo ""
+        # Capture verbose information for all devices, along with hex
+        # dump of whole configuration space
+        echo "$lspci -nnDvvvxxx"
+        echo ""
+        $lspci -nnDvvvxxx 2> /dev/null
     else
         echo "Skipping lspci output (lspci not found)"
         echo ""
